@@ -1,4 +1,5 @@
 from enum import Enum
+from pathlib import Path 
 
 from numpy import loadtxt
 
@@ -7,7 +8,7 @@ from ffast.preprocessor import PreprocessingPipeline
 PREPROCESSOR = PreprocessingPipeline()
 METAPHONES = "ABCEFHIJKLMNOPRSTUWXY0. "
 SIZE_METAPHONES = len(METAPHONES)
-PATH = "poincare/poincare.txt"
+PATH = Path(__file__).parent/"poincare.txt"
 raw_vocab = loadtxt(PATH,usecols=0,dtype=str)
 VOCABULARY = list(map(PREPROCESSOR.normalise,raw_vocab))
 VECTORS = loadtxt(PATH,usecols=range(1,101))
